@@ -53,42 +53,12 @@ class Domoticz(IPlugin):
 #				resp = requests.get (req)
 				log.msg("resp  :  %s" % (resp))
 		if bodies == "":
-			bodies = "j'ai rien compris"
+			bodies = "j'ai rien compris aux switch"
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
 			"body": bodies
 		}
 
-	def heatingcontrol(self, jsonInput):
-		bodies = ""
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
-		else:
-			bodies = "pas de lieu"
-
-		if jsonInput['outcome']['entities']['on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['on_off']['value']
-		else:
-			bodies = "pas de on/off"
-#
-		idex= location + "_" + on_off
-		log.msg("index :  %s" % (idex))		
-		for rs in self.configuration_plugin['param_dz']:
-			log.msg("ids  :  %s" % (rs['ids']))
-			if rs['ids'] == idex :
-#				log.msg("index trouvé :  ***")
-				bodies = rs['boy']
-				log.msg("BODIES  :  %s" % (bodies))
-				log.msg("on off  :  %s" % (on_off))
-				log.msg("number  :  %s" % (int(rs['idx'])))
-				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%s&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
-#				log.msg("resp  :  %s" % (req))				
-#				resp = requests.get (req)
-				log.msg("resp  :  %s" % (resp))
-		return {"plugin": "Domoticz",
-			"method": "switchlight",
-			"body": bodies
-		}
 
 	def devices(self, jsonInput):
 		bodies = ""
@@ -97,10 +67,10 @@ class Domoticz(IPlugin):
 		else:
 			bodies = "pas de lieu"
 
-		if jsonInput['outcome']['entities']['on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['on_off']['value']
+		if jsonInput['outcome']['entities']['local_search_query']['value'] :
+			local = jsonInput['outcome']['entities']['local_search_query']['value']
 		else:
-			bodies = "pas de on/off"
+			bodies = "pas de local_search_query"
 #
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))		
@@ -110,12 +80,14 @@ class Domoticz(IPlugin):
 #				log.msg("index trouvé :  ***")
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
-				log.msg("on off  :  %s" % (on_off))
+				log.msg("local  :  %s" % (local))
 				log.msg("number  :  %s" % (int(rs['idx'])))
-				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%s&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
+		#		resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%s&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
 #				log.msg("resp  :  %s" % (req))				
 #				resp = requests.get (req)
 				log.msg("resp  :  %s" % (resp))
+		if bodies == "":
+			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
 			"body": bodies
